@@ -244,10 +244,6 @@ def main(argv=None):
     time_ui = forest.components.TimeUI()
     time_ui.connect(store)
 
-    # Add snippet of text for user
-    headline = forest.components.Headline()
-    headline.connect(store)
-
     # Connect renderer.visible states to store
     artist = layers.Artist(renderers)
     artist.connect(store)
@@ -257,9 +253,21 @@ def main(argv=None):
     layers_ui.connect(store)
 
     # Connect tools controls
-    tools_panel = tools.ToolsPanel()
+
+    display_names = {
+            "time_series": "Display Time Series",
+            "profile": "Display Profile"
+        }
+    available_features = {k: display_names[k]
+                          for k in display_names.keys() if config.features[k]}
+
+    tools_panel = tools.ToolsPanel(available_features)
     tools_panel.connect(store)
 
+    # Navbar components
+    navbar = Navbar(show_diagram_button=len(available_features) > 0)
+    navbar.connect(store)
+
     # Connect tap listener
     tap_listener = screen.TapListener()
     tap_listener.connect(store)
@@ -349,52 +357,58 @@ def main(argv=None):
             title="Settings")
         ])
 
-    # Series sub-figure widget
-    series_figure = bokeh.plotting.figure(
-                plot_width=400,
-                plot_height=200,
-                x_axis_type="datetime",
-                toolbar_location=None,
-                border_fill_alpha=0)
-    series_figure.toolbar.logo = None
+    tool_figures = {}
+    if config.features["time_series"]:
+        # Series sub-figure widget
+        series_figure = bokeh.plotting.figure(
+                    plot_width=400,
+                    plot_height=200,
+                    x_axis_type="datetime",
+                    toolbar_location=None,
+                    border_fill_alpha=0)
+        series_figure.toolbar.logo = None
 
-    # Profile sub-figure widget
-    profile_figure = bokeh.plotting.figure(
-                plot_width=300,
-                plot_height=450,
-                toolbar_location=None,
-                border_fill_alpha=0)
-    profile_figure.toolbar.logo = None
-    profile_figure.y_range.flipped = True
+        series_view = series.SeriesView.from_groups(
+                series_figure,
+                config.file_groups)
+        series_view.add_subscriber(store.dispatch)
+        series_args = (rx.Stream()
+                    .listen_to(store)
+                    .map(series.select_args)
+                    .filter(lambda x: x is not None)
+                    .distinct())
+        series_args.map(lambda a: series_view.render(*a))
+        series_args.map(print)  # Note: map(print) creates None stream
 
-    tool_layout = tools.ToolLayout(series_figure, profile_figure)
+        tool_figures["series_figure"] = series_figure
+
+    if config.features["profile"]:
+        # Profile sub-figure widget
+        profile_figure = bokeh.plotting.figure(
+                    plot_width=300,
+                    plot_height=450,
+                    toolbar_location=None,
+                    border_fill_alpha=0)
+        profile_figure.toolbar.logo = None
+        profile_figure.y_range.flipped = True
+
+        profile_view = profile.ProfileView.from_groups(
+                profile_figure,
+                config.file_groups)
+        profile_view.add_subscriber(store.dispatch)
+        profile_args = (rx.Stream()
+                    .listen_to(store)
+                    .map(profile.select_args)
+                    .filter(lambda x: x is not None)
+                    .distinct())
+        profile_args.map(lambda a: profile_view.render(*a))
+        profile_args.map(print)  # Note: map(print) creates None stream
+
+        tool_figures["profile_figure"] = profile_figure
+
+    tool_layout = tools.ToolLayout(**tool_figures)
     tool_layout.connect(store)
 
-    series_view = series.SeriesView.from_groups(
-            series_figure,
-            config.file_groups)
-    series_view.add_subscriber(store.dispatch)
-    series_args = (rx.Stream()
-                .listen_to(store)
-                .map(series.select_args)
-                .filter(lambda x: x is not None)
-                .distinct())
-    series_args.map(lambda a: series_view.render(*a))
-    series_args.map(print)  # Note: map(print) creates None stream
-
-    profile_view = profile.ProfileView.from_groups(
-            profile_figure,
-            config.file_groups)
-    profile_view.add_subscriber(store.dispatch)
-    profile_args = (rx.Stream()
-                .listen_to(store)
-                .map(profile.select_args)
-                .filter(lambda x: x is not None)
-                .distinct())
-    profile_args.map(lambda a: profile_view.render(*a))
-    profile_args.map(print)  # Note: map(print) creates None stream
-
-
     for f in figures:
         f.on_event(bokeh.events.Tap, tap_listener.update_xy)
         marker = screen.MarkDraw(f).connect(store)
@@ -403,6 +417,7 @@ def main(argv=None):
             tabs,
             name="controls")
 
+
     # Add key press support
     key_press = keys.KeyPress()
     key_press.add_subscriber(store.dispatch)
@@ -412,22 +427,60 @@ def main(argv=None):
     document.add_root(control_root)
     document.add_root(
         bokeh.layouts.column(
-            tools_panel.buttons["toggle_time_series"],
-            tools_panel.buttons["toggle_profile"],
+            tools_panel.layout,
             tool_layout.layout,
             width=400,
             name="series"))
     document.add_root(
         bokeh.layouts.row(time_ui.layout, name="time"))
-    document.add_root(
-        bokeh.layouts.column(headline.layout, name="headline",
-                          sizing_mode="stretch_width"))
+    for root in navbar.roots:
+        document.add_root(root)
     document.add_root(
         bokeh.layouts.row(colorbar_ui.layout, name="colorbar"))
     document.add_root(figure_row.layout)
     document.add_root(key_press.hidden_button)
 
 
+class Navbar:
+    """Collection of navbar components"""
+    def __init__(self, show_diagram_button=True):
+        self.headline = forest.components.Headline()
+        self.headline.layout.name = "headline"
+
+        self.buttons = {}
+        # Add button to control left drawer
+        key = "sidenav_button"
+        self.buttons[key] = bokeh.models.Button(
+            label="Settings",
+            name=key)
+        custom_js = bokeh.models.CustomJS(code="""
+            openId("sidenav");
+        """)
+        self.buttons[key].js_on_click(custom_js)
+
+        # Add button to control right drawer
+        key = "diagrams_button"
+        self.buttons[key] = bokeh.models.Button(
+            label="Diagrams",
+            css_classes=["float-right"],
+            name=key)
+        custom_js = bokeh.models.CustomJS(code="""
+            openId("diagrams");
+        """)
+        self.buttons[key].js_on_click(custom_js)
+
+        roots = [
+            self.buttons["sidenav_button"],
+            self.headline.layout,
+        ]
+        if show_diagram_button:
+            roots.append(self.buttons["diagrams_button"])
+        self.roots = roots
+
+    def connect(self, store):
+        self.headline.connect(store)
+
+
 def any_none(obj, attrs):
     return any([getattr(obj, x) is None for x in attrs])
 
