@@ -10,7 +10,6 @@ from forest import (
         earth_networks,
         db,
         gridded_forecast,
-        ghrsstl4,
         unified_model,
         eida50,
         rdt,
@@ -18,6 +17,8 @@ from forest import (
         saf,
         nearcast)
 
+from forest.drivers import ghrsstl4
+
 
 class Navigator:
     def __init__(self, config):
